Test repository to experiment with GitLab [CI components](https://docs.gitlab.com/ee/ci/components/).

[TOC]

## General tips
* Use the `name` argument to use a component multiple times in a single CI/CD pipeline
* Use a `name` stating with a dot and extend the job if you need more customization

## Components

### Kaniko build

The `kaniko-build` CI/CD component provides a template to build Docker images within a pipeline using [Kaniko](https://github.com/GoogleContainerTools/kaniko).

#### Parameter

| Parameter           | Description                                                         | Type     | Default                 |
| ------------------- | ------------------------------------------------------------------- | -------- | ----------------------- |
| `dockerfile`        | Path of the Dockerfile relative to the project directory.           | `string` | `Dockerfile`            |
| `image_repo`        | Name of the Docker repository including the registry path           | `string` | `$CI_REGISTRY_IMAGE`    |
| `image_tag`         | Tag of the Docker image                                             | `string` | `$CI_COMMIT_TAG`        |
| `stage`             | Stage of the CI/CD job                                              | `string` | `build`                 |
| `name`              | Name of the CI/CD job                                               | `string` | `docker-build`          |
| `kaniko_tag`        | Kaniko docker image tag. THe job needs debug variants of Kaniko.    | `string` | `v1.20.1-debug`         |
| `registry`          | Hostname (and port) of the Docker registry to which the job logs in | `string` | `$CI_REGISTRY`          |
| `registry_user`     | Username to authenticate with the Docker registry                   | `string` | `$CI_REGISTRY_USER`     |
| `registry_password` | Password to authenticate with the Docker registry                   | `string` | `$CI_REGISTRY_PASSWORD` |

#### Examples

```yaml
stages:
  - build

include:
  - component: gitlab.sauerburger.com/sauerburger-it/devops/kaniko-build@0.1.0
    rules: 
    - if: $CI_COMMIT_TAG

  - component: gitlab.sauerburger.com/sauerburger-it/devops/kaniko-build@0.1.0
    rules:
    - if: $CI_COMMIT_TAG
    inputs:
      name: second-image  # Overwrite image name to allow multiple jobs
```

### Docker image retag

The `buildx-retag` CI/CD component provides a template to push existing Docker image to the registry using a different tag. The
operation doesn't require the job to download the image artifacts.

#### Parameter

| Parameter           | Description                                                         | Type     | Default                             |
| ------------------- | ------------------------------------------------------------------- | -------- | ----------------------------------- |
| `source`            | Repository and tag of the existing source Docker image.             | `string` | `$CI_REGISTRY_IMAGE:$CI_COMMIT_TAG` |
| `target`            | Repository and tag of the Docker image to push.                     | `string` | `$CI_REGISTRY_IAMGE:latest`         |
| `stage`             | Stage of the CI/CD job                                              | `string` | `deploy`                            |
| `name`              | Name of the CI/CD job                                               | `string` | `buildx-retag`                      |
| `docker_tag`        | "Docker" Docker image tag.                                          | `string` | `25.0.3-cli`                        |
| `registry`          | Hostname (and port) of the Docker registry to which the job logs in | `string` | `$CI_REGISTRY`                      |
| `registry_user`     | Username to authenticate with the Docker registry                   | `string` | `$CI_REGISTRY_USER`                 |
| `registry_password` | Password to authenticate with the Docker registry                   | `string` | `$CI_REGISTRY_PASSWORD`             |

#### Examples

```yaml
stages:
  - deploy

include:
  - component: gitlab.sauerburger.com/sauerburger-it/devops/buildx-retag@0.1.0
    rules:
    - if: $CI_COMMIT_TAG
      when: manual
